Class: Processing::Context
- Inherits:
-
Object
- Object
- Processing::Context
- Includes:
- GraphicsContext, Xot::Inspectable
- Defined in:
- lib/processing/context.rb
Overview
Processing context
Constant Summary collapse
- Capture =
Processing::Capture
- Font =
Processing::Font
- Graphics =
Processing::Graphics
- Image =
Processing::Image
- Shader =
Processing::Shader
- TextBounds =
Processing::TextBounds
- Touch =
Processing::Touch
- Vector =
Processing::Vector
Constants included from GraphicsContext
GraphicsContext::ADD, GraphicsContext::ALT, GraphicsContext::BACKSPACE, GraphicsContext::BASELINE, GraphicsContext::BLEND, GraphicsContext::BLUR, GraphicsContext::BOTTOM, GraphicsContext::CAPSLOCK, GraphicsContext::CENTER, GraphicsContext::CLEAR, GraphicsContext::COMMAND, GraphicsContext::CONTROL, GraphicsContext::CORNER, GraphicsContext::CORNERS, GraphicsContext::DARKEST, GraphicsContext::DEGREES, GraphicsContext::DELETE, GraphicsContext::DOWN, GraphicsContext::ENTER, GraphicsContext::ESC, GraphicsContext::EXCLUSION, GraphicsContext::F1, GraphicsContext::F10, GraphicsContext::F11, GraphicsContext::F12, GraphicsContext::F13, GraphicsContext::F14, GraphicsContext::F15, GraphicsContext::F16, GraphicsContext::F17, GraphicsContext::F18, GraphicsContext::F19, GraphicsContext::F2, GraphicsContext::F20, GraphicsContext::F21, GraphicsContext::F22, GraphicsContext::F23, GraphicsContext::F24, GraphicsContext::F3, GraphicsContext::F4, GraphicsContext::F5, GraphicsContext::F6, GraphicsContext::F7, GraphicsContext::F8, GraphicsContext::F9, GraphicsContext::FUNCTION, GraphicsContext::GRAY, GraphicsContext::HALF_PI, GraphicsContext::HELP, GraphicsContext::HOME, GraphicsContext::HSB, GraphicsContext::INVERT, GraphicsContext::LEFT, GraphicsContext::LIGHTEST, GraphicsContext::MITER, GraphicsContext::MULTIPLY, GraphicsContext::OPTION, GraphicsContext::PAGEDOWN, GraphicsContext::PAGEUP, GraphicsContext::PI, GraphicsContext::PROJECT, GraphicsContext::QUARTER_PI, GraphicsContext::RADIANS, GraphicsContext::RADIUS, GraphicsContext::REPLACE, GraphicsContext::RGB, GraphicsContext::RGBA, GraphicsContext::RIGHT, GraphicsContext::ROUND, GraphicsContext::SCREEN, GraphicsContext::SECTION, GraphicsContext::SHIFT, GraphicsContext::SPACE, GraphicsContext::SQUARE, GraphicsContext::SUBTRACT, GraphicsContext::TAB, GraphicsContext::TAU, GraphicsContext::THRESHOLD, GraphicsContext::TOP, GraphicsContext::TWO_PI, GraphicsContext::UP, GraphicsContext::WIN
Instance Method Summary collapse
-
#createCanvas(width, height, pixelDensity: self.pixelDensity) ⇒ nil
Changes canvas size.
-
#displayDensity ⇒ Numeric
Returns the pixel density of the display.
-
#displayHeight ⇒ Numeric
Returns the height of the display.
-
#displayWidth ⇒ Numeric
Returns the width of the display.
-
#draw(&block) ⇒ nil
Defines draw block.
-
#frameCount ⇒ Integer
Returns the number of frames since the program started.
-
#frameRate ⇒ Float
Returns the number of frames per second.
-
#key ⇒ String
Returns the last key that was pressed or released.
-
#keyCode ⇒ Symbol
Returns the last key code that was pressed or released.
-
#keyPressed(&block) ⇒ Boolean
Defines keyPressed block.
-
#keyReleased(&block) ⇒ nil
Defines keyReleased block.
-
#keyTyped(&block) ⇒ nil
Defines keyTyped block.
-
#loop ⇒ nil
Enables calling draw block on every frame.
-
#motion(&block) ⇒ nil
Defines motion block.
-
#motionGravity ⇒ Vector
Returns vector for real world gravity.
-
#mouseButton ⇒ Numeric
Returns which mouse button was pressed.
-
#mouseClicked(&block) ⇒ nil
Defines mouseClicked block.
-
#mouseDragged(&block) ⇒ nil
Defines mouseDragged block.
-
#mouseMoved(&block) ⇒ nil
Defines mouseMoved block.
-
#mousePressed(&block) ⇒ Boolean
Defines mousePressed block.
-
#mouseReleased(&block) ⇒ nil
Defines mouseReleased block.
-
#mouseX ⇒ Numeric
Returns mouse x position.
-
#mouseY ⇒ Numeric
Returns mouse y position.
-
#noLoop ⇒ nil
Disables calling draw block on every frame.
-
#pixelDensity(density = nil) ⇒ Numeric
Changes and returns canvas pixel density.
-
#pmouseX ⇒ Numeric
Returns mouse x position in previous frame.
-
#pmouseY ⇒ Numeric
Returns mouse y position in previous frame.
-
#redraw ⇒ nil
Calls draw block to redraw frame.
-
#setTitle(title) ⇒ nil
Changes title of window.
-
#setup(&block) ⇒ nil
Defines setup block.
-
#size(width, height, pixelDensity: self.pixelDensity) ⇒ nil
Changes canvas size.
-
#touchEnded(&block) ⇒ nil
Defines touchEnded block.
-
#touches ⇒ Array
Returns array of touches.
-
#touchMoved(&block) ⇒ nil
Defines touchMoved block.
-
#touchStarted(&block) ⇒ nil
Defines touchStarted block.
-
#windowHeight ⇒ Numeric
Returns the height of the window.
-
#windowMove(x, y) ⇒ nil
Move the position of the window.
-
#windowMoved(&block) ⇒ nil
Defines windowMoved block.
-
#windowResizable(resizable) ⇒ nil
Makes the window resizable or not.
-
#windowResize(width, height) ⇒ nil
Sets the size of the window.
-
#windowResized(&block) ⇒ nil
Defines windowResized block.
-
#windowWidth ⇒ Numeric
Returns the width of the window.
-
#windowX ⇒ Numeric
Returns the x position of the window.
-
#windowY ⇒ Numeric
Returns the y position of the window.
Methods included from GraphicsContext
#abs, #acos, #angleMode, #arc, #asin, #atan, #atan2, #background, #bezier, #blend, #blendMode, #ceil, #circle, #clip, #colorMode, #constrain, #copy, #cos, #createCapture, #createGraphics, #createImage, #createShader, #createVector, #curve, #degrees, #dist, #ellipse, #ellipseMode, #exp, #fill, #filter, #floor, #height, #image, #imageMode, #lerp, #line, #loadImage, #loadShader, #log, #mag, #map, #max, #min, #noClip, #noFill, #noStroke, #noTint, #noise, #norm, #pixelHeight, #pixelWidth, #point, #pop, #popMatrix, #popStyle, #pow, #push, #pushMatrix, #pushStyle, #quad, #radians, #random, #rect, #rectMode, #resetMatrix, #resetShader, #rotate, #round, #save, #scale, #shader, #sin, #sq, #sqrt, #square, #stroke, #strokeCap, #strokeJoin, #strokeWeight, #tan, #text, #textAlign, #textAscent, #textDescent, #textFont, #textSize, #textWidth, #tint, #translate, #triangle, #width
Instance Method Details
#createCanvas(width, height, pixelDensity: self.pixelDensity) ⇒ nil
Changes canvas size.
345 346 347 348 |
# File 'lib/processing/context.rb', line 345 def createCanvas(width, height, pixelDensity: self.pixelDensity) resizeCanvas__ :createCanvas, width, height, pixelDensity nil end |
#displayDensity ⇒ Numeric
Returns the pixel density of the display.
400 401 402 |
# File 'lib/processing/context.rb', line 400 def displayDensity() @window__.painter.pixel_density end |
#displayHeight ⇒ Numeric
Returns the height of the display.
392 393 394 |
# File 'lib/processing/context.rb', line 392 def displayHeight() @window__.screen.height end |
#displayWidth ⇒ Numeric
Returns the width of the display.
384 385 386 |
# File 'lib/processing/context.rb', line 384 def displayWidth() @window__.screen.width end |
#draw(&block) ⇒ nil
Defines draw block.
193 194 195 196 |
# File 'lib/processing/context.rb', line 193 def draw(&block) @drawBlock__ = block if block nil end |
#frameCount ⇒ Integer
Returns the number of frames since the program started.
475 476 477 |
# File 'lib/processing/context.rb', line 475 def frameCount() @frameCount__ end |
#frameRate ⇒ Float
Returns the number of frames per second.
483 484 485 |
# File 'lib/processing/context.rb', line 483 def frameRate() @window__.event.fps end |
#key ⇒ String
Returns the last key that was pressed or released.
491 492 493 |
# File 'lib/processing/context.rb', line 491 def key() @key__ end |
#keyCode ⇒ Symbol
Returns the last key code that was pressed or released.
499 500 501 |
# File 'lib/processing/context.rb', line 499 def keyCode() @keyCode__ end |
#keyPressed(&block) ⇒ Boolean
Defines keyPressed block.
202 203 204 205 |
# File 'lib/processing/context.rb', line 202 def keyPressed(&block) @keyPressedBlock__ = block if block not @keysPressed__.empty? end |
#keyReleased(&block) ⇒ nil
Defines keyReleased block.
211 212 213 214 |
# File 'lib/processing/context.rb', line 211 def keyReleased(&block) @keyReleasedBlock__ = block if block nil end |
#keyTyped(&block) ⇒ nil
Defines keyTyped block.
220 221 222 223 |
# File 'lib/processing/context.rb', line 220 def keyTyped(&block) @keyTypedBlock__ = block if block nil end |
#loop ⇒ nil
Enables calling draw block on every frame.
563 564 565 |
# File 'lib/processing/context.rb', line 563 def loop() @loop__ = true end |
#motion(&block) ⇒ nil
Defines motion block.
319 320 321 322 |
# File 'lib/processing/context.rb', line 319 def motion(&block) @motionBlock__ = block if block nil end |
#motionGravity ⇒ Vector
Returns vector for real world gravity
555 556 557 |
# File 'lib/processing/context.rb', line 555 def motionGravity() @motionGravity__ end |
#mouseButton ⇒ Numeric
Returns which mouse button was pressed
539 540 541 |
# File 'lib/processing/context.rb', line 539 def mouseButton() ((@pointersPressed__ + @pointersReleased__) & [LEFT, RIGHT, CENTER]).last end |
#mouseClicked(&block) ⇒ nil
Defines mouseClicked block.
265 266 267 268 |
# File 'lib/processing/context.rb', line 265 def mouseClicked(&block) @mouseClickedBlock__ = block if block nil end |
#mouseDragged(&block) ⇒ nil
Defines mouseDragged block.
256 257 258 259 |
# File 'lib/processing/context.rb', line 256 def mouseDragged(&block) @mouseDraggedBlock__ = block if block nil end |
#mouseMoved(&block) ⇒ nil
Defines mouseMoved block.
247 248 249 250 |
# File 'lib/processing/context.rb', line 247 def mouseMoved(&block) @mouseMovedBlock__ = block if block nil end |
#mousePressed(&block) ⇒ Boolean
Defines mousePressed block.
229 230 231 232 |
# File 'lib/processing/context.rb', line 229 def mousePressed(&block) @mousePressedBlock__ = block if block not @pointersPressed__.empty? end |
#mouseReleased(&block) ⇒ nil
Defines mouseReleased block.
238 239 240 241 |
# File 'lib/processing/context.rb', line 238 def mouseReleased(&block) @mouseReleasedBlock__ = block if block nil end |
#mouseX ⇒ Numeric
Returns mouse x position
507 508 509 |
# File 'lib/processing/context.rb', line 507 def mouseX() @pointerPos__.x end |
#mouseY ⇒ Numeric
Returns mouse y position
515 516 517 |
# File 'lib/processing/context.rb', line 515 def mouseY() @pointerPos__.y end |
#noLoop ⇒ nil
Disables calling draw block on every frame.
571 572 573 |
# File 'lib/processing/context.rb', line 571 def noLoop() @loop__ = false end |
#pixelDensity(density = nil) ⇒ Numeric
Changes and returns canvas pixel density.
367 368 369 370 |
# File 'lib/processing/context.rb', line 367 def pixelDensity(density = nil) resizeCanvas__ :pixelDensity, width, height, density if density @painter__.pixel_density end |
#pmouseX ⇒ Numeric
Returns mouse x position in previous frame
523 524 525 |
# File 'lib/processing/context.rb', line 523 def pmouseX() @pointerPrevPos__.x end |
#pmouseY ⇒ Numeric
Returns mouse y position in previous frame
531 532 533 |
# File 'lib/processing/context.rb', line 531 def pmouseY() @pointerPrevPos__.y end |
#redraw ⇒ nil
Calls draw block to redraw frame.
579 580 581 |
# File 'lib/processing/context.rb', line 579 def redraw() @redraw__ = true end |
#setTitle(title) ⇒ nil
Changes title of window.
356 357 358 359 |
# File 'lib/processing/context.rb', line 356 def setTitle(title) @window__.title = title nil end |
#setup(&block) ⇒ nil
Defines setup block.
165 166 167 168 |
# File 'lib/processing/context.rb', line 165 def setup(&block) @window__.setup = block nil end |
#size(width, height, pixelDensity: self.pixelDensity) ⇒ nil
Changes canvas size.
332 333 334 335 |
# File 'lib/processing/context.rb', line 332 def size(width, height, pixelDensity: self.pixelDensity) resizeCanvas__ :size, width, height, pixelDensity nil end |
#touchEnded(&block) ⇒ nil
Defines touchEnded block.
283 284 285 286 |
# File 'lib/processing/context.rb', line 283 def touchEnded(&block) @touchEndedBlock__ = block if block nil end |
#touches ⇒ Array
Returns array of touches
547 548 549 |
# File 'lib/processing/context.rb', line 547 def touches() @touches__ end |
#touchMoved(&block) ⇒ nil
Defines touchMoved block.
292 293 294 295 |
# File 'lib/processing/context.rb', line 292 def touchMoved(&block) @touchMovedBlock__ = block if block nil end |
#touchStarted(&block) ⇒ nil
Defines touchStarted block.
274 275 276 277 |
# File 'lib/processing/context.rb', line 274 def touchStarted(&block) @touchStartedBlock__ = block if block nil end |
#windowHeight ⇒ Numeric
Returns the height of the window.
467 468 469 |
# File 'lib/processing/context.rb', line 467 def windowHeight() @window__.height end |
#windowMove(x, y) ⇒ nil
Move the position of the window.
411 412 413 414 |
# File 'lib/processing/context.rb', line 411 def windowMove(x, y) @window__.pos = [x, y] nil end |
#windowMoved(&block) ⇒ nil
Defines windowMoved block.
301 302 303 304 |
# File 'lib/processing/context.rb', line 301 def windowMoved(&block) @windowMovedBlock__ = block if block nil end |
#windowResizable(resizable) ⇒ nil
Makes the window resizable or not.
434 435 436 437 |
# File 'lib/processing/context.rb', line 434 def windowResizable(resizable) @window__.resizable = resizable nil end |
#windowResize(width, height) ⇒ nil
Sets the size of the window.
423 424 425 426 |
# File 'lib/processing/context.rb', line 423 def windowResize(width, height) @window__.size = [width, height] nil end |
#windowResized(&block) ⇒ nil
Defines windowResized block.
310 311 312 313 |
# File 'lib/processing/context.rb', line 310 def windowResized(&block) @windowResizedBlock__ = block if block nil end |
#windowWidth ⇒ Numeric
Returns the width of the window.
459 460 461 |
# File 'lib/processing/context.rb', line 459 def windowWidth() @window__.width end |
#windowX ⇒ Numeric
Returns the x position of the window.
443 444 445 |
# File 'lib/processing/context.rb', line 443 def windowX() @window__.x end |
#windowY ⇒ Numeric
Returns the y position of the window.
451 452 453 |
# File 'lib/processing/context.rb', line 451 def windowY() @window__.y end |